function [dat,str]=mmsearch(branch,varargin)
% MMSEARCH Full-text and keyword search in Model Manager
%
% MMSEARCH(BRANCH, SEARCHTERM) performs full-text search for SEARCHTERM in 
% the branch BRANCH. The limit on the number of returned items is 10,000.
% In order to specify a limit use this syntax
% MMSEARCH(BRANCH, 'fulltext', SEARCHTERM, 'limit', 100)
%
% MMSEARCH(BRANCH, KEYWORD, TERM, ...) perform a search for TERM in the
% branch BRANCH. Multiple KEYWORDs can be added using an implicit AND 
% operation between the search terms. This syntax can not be combined with
% the 'fulltext' option.
%
%  Valid property/value pairs include:
%  Property        Value/{Default}   Description
%  -----------------------------------------------------------------------
%  branch          String            Branch
%  commitcomment   String            Commit comment
%  component       String            Component field expression
%  computeddata    String            Computed data size
%  description     String            Description
%  filename        String            Filename
%  filetype        String            File type (extension)
%  itemkey         String            Item key
%  itemsavetype    String            Item save type
%  itemversionkey  String            Item version key
%  itemversiontype String            Item version type
%  lastmodified    String            Last modified date
%  lastmodifiedby  String            Last modified by
%  node            String            Node field expression
%  owner           String            Owner (name)
%  part            String            Part type (geometry)
%  physics         String            Physics field expression
%  repository      String            Repository
%  saved           String            Saved date
%  savedby         String            Saved by (name)
%  setting         String            Setting field expression
%  size            String            Size
%  tag             String            Assigned tag
%  tagkey          String            Key for assigned tag
%  title           String            Title
%  fulltext        String            Full text search term
%  limit           Integer {500}     Maxmimum number of matches
%
% % Example: Search for filenames that either contains "free" or contains "chem"
% branch = mmgetbranch('Main', 'Repository 1', 'MyDatabase')
% dat = mmsearch(branch, '@filename:*free* OR @filename:*chem*')
%
% % Example: Search for models where the title is "busbar"
% branch = mmgetbranch('Main', 'Repository 1', 'MyDatabase')
% dat = mmsearch(branch, 'title', 'busbar')
%
% % Example: Search for models having a node of type analytic and a savetype of "regular"
% dat = mmsearch(branch, 'node', '@type:analytic', 'savetype', 'regular')
%
% See also: mmgetbranch

narginchk(2,inf)

import com.comsol.api.database.*;

if length(varargin)==1
    str = varargin{1};
    dat = mmsearch_raw(branch, str, 10000);
    return
end

%sig: required, branch, "type=com.comsol.api.database.clientimpl.DatabaseClientApiEndpoints$BranchClient", "Branch object"
props = {'branch', '', 'string', 'Branch'
    'commitcomment', '', 'string', 'Commit comment'
    'component', '', 'string', 'Component'
    'computeddata', '', 'string', 'Size of computed data'
    'description', '', 'string', 'Description'
    'filename', '', 'string', 'Filename'
    'filetype', '', 'string', 'File extension'
    'itemkey', '', 'string', 'Item key'
    'itemsavetype', '', 'c:draft|recovery|regular', 'Item save type'
    'itemversionkey', '', 'string', 'Item version key'
    'itemversiontype', '', 'c:model|application|file', 'Item version type'
    'lastmodified', '', 'string', 'Last modified date and time'
    'lastmodifiedby', '', 'string', 'Last modified by'
    'node', '', 'string', 'Node'
    'owner', '', 'string', 'Owner'
    'part', '', 'c:geometry', 'Part'
    'physics', '', 'string', 'Physics'
    'repository', '', 'string', 'Repository'
    'saved', '', 'string', 'Saved date and time'
    'savedby', '', 'string', 'Saved by'
    'setting', '', 'string', 'Setting'
    'size', '', 'string', 'Size'
    'tag', '', 'string', 'Tag'
    'tagkey', '', 'string', 'Tag key'
    'title', '', 'string', 'Title'
    'fulltext', '', 'string', 'Full-text search'
    'limit', 500, 'posint', 'Limit number of results'};

prop = proputil(props, varargin);

% branch, repository, size, computedData
% Available: branch, comment, computedData, description, fileType, filename,
%    itemKey, itemType, itemVersionKey, itemVersionType, lastModified,
%    lastModifiedBy, owner, part, repository, saveType, saved, savedBy, size,
%    tag, tagKey, title

if ~isempty(prop.fulltext)
    dat = mmsearch_raw(branch, prop.fulltext, prop.limit);
else
    str = '';
    for i=1:size(props,1)
        key = props{i,1};
        if ismember(key, {'fulltext' 'limit'})
            continue
        end
        value = prop.(key);
        
        % !!! check for values that only contain whitespace
        if ~isempty(value)
            switch key
                case {'component' 'node' 'physics' 'setting'}
                    str = [str ' @' key '{' value '}'];
                otherwise
                    str = [str ' @' key ':(' value ')'];
            end
        end
    end
    
    if isempty(str)
        error('Nothing to search for')
    end
    
    str = strtrim(str);
    dat = mmsearch_raw(branch, str, prop.limit);
end
end



function dat=mmsearch_raw(branch, searchterm, limit)

narginchk(3, 3)

if ~isa(branch, 'com.comsol.api.database.clientimpl.DatabaseClientApiEndpoints$BranchClient')
    branch = mmgetbranch(branch);
end

try
    si = branch.searchItems(searchterm);
    if si.totalCount==0
        dat = [];
        return
    end
catch err
    f = strfind(err.message, 'Stack trace');
    if any(f)
        msg = strtrim( err.message(1:f-1) );
    else
        msg = err.message;
    end
    if any(strfind(msg, 'Invalid search syntax'))
    end
    msg = sprintf('%s (%d): %s', err.stack(1).name, err.stack(1).line, msg);
    error(strrep(msg,[char(13) char(10)],char(10)))
end

iter = si.iterator;
i = 1;
while iter.hasNext
    item = iter.next;
    
    d = mmiteminfo(item, '-fast');
    fn = fieldnames(d);
    for k=1:length(fn)
        dat(i).(fn{k}) = d.(fn{k});
    end

    dat(i).item = item;

    i = i+1;
    if i>limit
        break
    end
end

end
