function varargout=mphglobal(model,expr,varargin)
% MPHGLOBAL Evaluate global quantities
%
%   [D1,...,DN] = MPHGLOBAL(MODEL,{E1,...,EN},...) returns the
%   results from evaluating the global quantities specified in the string
%   expressions E1,...,EN.
%
%   [D1,...,DN,UNIT] = MPHGLOBAL(MODEL,{E1,...,EN},...) also returns the
%   unit of the expressions E1,...,EN. UNIT is a Nx1 cell array.
%
%   Valid property/value pairs include:
%   Property      Value/{Default}        Description
%   -----------------------------------------------------------------------
%   complexfun    'off' | {'on'}         Use complex-valued functions with
%                                        real input
%   complexout    'off' | {'on'}         Return complex values
%   const         Cell array             Name and value pair of constants
%   dataset       String {''}            Data set tag
%   matherr       {'off'} | 'on'         Error for undefined operation
%                                        or expressions
%   outersolnum   Positive integer {1} | Solution number for parametric
%                 'end' | 'all'          sweep
%   output        {''} | 'cell'          Output is a cell array
%   phase         Scalar {0}             Phase angle in degrees
%   solnum        Integer vector |       Solution for evaluation
%                 'end' | {'all'}
%   t             Double vector {''}     Time for evaluation
%   unit          String {''} |          Unit to use for the evaluation
%                 Cell array
%
%   The property solnum is used to select the inner solution number, e.g. when
%   a parametric, eigenvalue or time-dependent solver has been used.
%   The property outersolnum is used to  select the outer solution number, e.g.
%   when a parametric sweep has been used in the study step node.
%
%   See the entry MPHGLOBAL in the LiveLink for MATLAB User's Guide for
%   more information about the property/values.
%
%   Example 1: Evaluate global expression on node points
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Add an operator to evaluate maximum value over all domains:
%     model.cpl.create('maxop', 'Maximum', 'geom1').selection.all;
%     % Create a stationary study:
%     std = model.study.create('std');
%     std.feature.create('stat','Stationary');
%     % Run the study study:
%     std.run;
%
%     % Evaluate the maximum temperature in the model
%     maxT = mphglobal(model,'maxop(T)')
%
%     % Evaluate the maximum temperature in the model in degrees Celsius
%     maxT = mphglobal(model,'maxop(T)','unit','degC')
%
%   Example 2: Evaluate expression using several solution dataset
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Add an operator to evaluate maximum value over all domains:
%     model.cpl.create('maxop', 'Maximum', 'geom1').selection.all;
%     % Create a study combining a parametric sweep and a transient
%     % study step:
%     std = model.study.create('std');
%     param = std.feature.create('param','Parametric');
%     time = std.feature.create('time','Transient');
%     % Set the time stepping and the parametric sweep parameters:
%     time.set('tlist', 'range(0,1,25)');
%     param.setIndex('pname','power',0).setIndex('plistarr','30 60 90',0);
%     % Run the study:
%     std.run;
%
%     % Evaluate maxop(T) at every time step computed with power set to 30:
%     maxT = mphglobal(model,'maxop(T)','dataset','dset2')
%
%     % Evaluate maxop(T) for the first and fifth time step:
%     maxT = mphglobal(model,'maxop(T)','dataset','dset2','solnum',[1,5])
%
%     % Evaluate maxop(T) at 20.512 sec:
%     maxT  = mphglobal(model,'maxop(T)','dataset','dset2','t',20.512)
%
%     % Evaluate maxop(T) at every time step computed with power set to 90:
%     maxT  = mphglobal(model,'maxop(T)','dataset','dset2','outersolnum',3)
%
%   See also: mpheval, mphevalglobalmatrix, mphevalpoint, mphevalpointmatrix,
%   mphint2, mphinterp

%   Copyright 2010-2023 COMSOL
