function varargout=mphint2(model,expr,edim,varargin)
% MPHINT2 Perform integration of expressions
%
%   [V1,...,VN] = MPHINT2(MODEL,{E1,...,EN},EDIM,...) evaluates the
%   integrals of the string expressions E1,...,EN and returns the result
%   in N matrices V1,...,VN with M rows and P columns. M is the number
%   of inner solution amd P the number of outer solution used for the
%   evaluation. EDIM defines the element dimension, as a string: 'line',
%   'surface', 'volume' or as an integer value.
%
%   [V1,...,VN,UNIT] = MPHINT2(MODEL,{E1,...,EN},EDIM,...) also returns the
%   units of the integral in a 1xN cell array.
%
%   Valid property/value pairs include:
%   Property     Value/{Default}               Description
%   -----------------------------------------------------------------------
%   dataseries    {'none'} | 'average' |       Data series operation
%                 'integral' | 'maximum' |
%                 'minimum' | 'rms' |
%                 'stddev' | 'variance'
%   dataset       String {''}                  Data set tag
%   intorder      Integer {4}                  Integration order
%   intsurface    'on' | {'off'}               Compute surface integral
%   intvolume     'on' | {'off'}               Compute volume integral
%   matrix        {'on'} | 'off'               Return data as a matrix or
%                                              as a cell array
%   method        {'auto'} | 'integration' |   Integration method
%                 'summation'
%   outersolnum   Positive integer {1} |       Solution number for
%                 'end' | 'all'                parametric sweep
%   selection     Integer vector | String |    Selection list or named
%                 {'all'}                      selection
%   solnum        Integer vector | 'end' |     Solution for evaluation
%                 {'all'}
%   squeeze       {'on'} | 'off'               Squeeze singleton dimensions
%   t             Double array {''}            Time for evaluation
%   unit          String {''} |                Unit to use for the evaluation
%                 Cell array
%
%   The property solnum is used to select the inner solution number, e.g. when 
%   a parametric, eigenvalue or time-dependent solver has been used.
%   The property outersolnum is used to  select the outer solution number, e.g. 
%   when a parametric sweep has been used in the study step node.
%   If matrix is set to 'off' the output return has a cell array format of
%   length P containing cell arrays of length M.
%
%   See the entry MPHINT2 in the LiveLink for MATLAB User's Guide for more
%   information about the property/values.
%
%   Example:
%     % Load the model model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a stationary study:
%     std = model.study.create('std');
%     std.feature.create('stat','Stationary');
%     % Run the study study:
%     std.run;
%     % Integrate the normal heat flux across all boundaries
%     [Q, unit] = mphint2(model,'ht.ntflux','surface')
%     % Integrate the normal heat flux across all exterior boundaries
%     [Q, unit] = mphint2(model,'ht.ntflux','surface',...
%        'selection',[1:5,7:12])
%
%   See also: mpheval, mphevalglobalmatrix, mphevalpoint, mphevalpointmatrix, 
%   mphglobal, mphinterp

%   Copyright 2012-2023 COMSOL
