function [plotdata,handles]=mphplot(model,varargin)
% MPHPLOT Render a plot group in a figure window
%
%   MPHPLOT(MODEL) opens a figure window and adds a menu where it is
%   possible to switch between all the different result plots in a model
%   as well as any geometry and mesh plots. A toolbar is added to the
%   figure that allows the user to control the use of views, lights, and
%   camera settings.
%
%   MPHPLOT(MODEL,PGTAG,...) renders the plot group tagged PGTAG from the
%   model object MODEL in a figure window in MATLAB.
%
%   PD = MPHPLOT(MODEL,PGTAG,...) also returns the plot data used in the
%   MATLAB figure in a cell array PD.
%
%   MPHPLOT(PD, ...) makes a plot using the post data structure PD that is
%   generated using the function MPHEVAL, MPHMESH or MPHPLOT.
%
%   Valid property/value pairs include:
%   Property         Value/{Default}          Description
%   -----------------------------------------------------------------------
%   axiscolor        {'gray'} | Char |         Symmetry axis color
%                    RGB array
%   colortable       String | {'rainbow'}      Color table used for plotting
%                                              post data structure
%   colortablesteps  Integer {256}             Number of steps in colortables*
%   createplot       {'on'} | 'off'            Create a plot
%   index            Integer | {1}             Index of variable to use for
%                                              plotting post data structure
%   mesh             {'on'} | 'off'            Plot the mesh when using post
%                                              data structure
%   parent           Double                    Parent axis
%   rangenum         Positive integer {''}     Color range bar (or legend) to
%                                              display
%   run              {'on'} | 'off'            Run the plot group node
%   server           'on' | {'off'}            Plot on server
%   view             String | {''} | 'auto'    View settings
%
%   * The minimum number of steps in colortables is 256.
%   ** The plot on server option requires that you start COMSOL with MATLAB in
%   graphics mode.
%   Only one color range bar and one legend bar is supported in a
%   MATLAB figure. When the option plot on server is active, all active
%   color range bar are displayed.
%   The property createplot is useful when extracting plot data structure on
%   machine without graphics display.
%
%   Example 1:
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a stationary study:
%     std = model.study.create('std');
%     std.feature.create('stat','Stationary');
%     % Run the study:
%     std.run;
%
%     % Create a plot group to display the solution:
%     model.result.dataset.create('mir', 'Mirror3D');
%     pg = model.result.create('pg', 'PlotGroup3D');
%     pg.set('data', 'mir');
%     surf1 = pg.feature.create('surf1', 'Surface');
%     surf1.set('colortable', 'Thermal');
%
%     % Display the plot settings pg using a MATLAB figure
%     mphplot(model,'pg')
%
%     % Combine plot types on the same plot group
%     surf2 = pg.feature.create('surf2', 'Surface');
%     surf2.set('data', 'dset1');
%     surf2.set('expr', 'ht.tfluxMag');
%
%     % Display the plot group and the color range bar of the the second
%     % plot type
%     mphplot(model,'pg','rangenum',2)
%
%     % Display the plot group on the server (*)
%     mphplot(model,'pg','server','on')
%
%   Example 2: Display expression value evaluated using MPHEVAL
%     % Load the model model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a stationary study:
%     std = model.study.create('std');
%     std.feature.create('stat','Stationary');
%     % Run the study:
%     std.run;
%
%     % Extract temperature and total heat flux magnitude in domain 2:
%     pd = mpheval(model, {'T', 'ht.tfluxMag'},'selection',2);
%     % Plot the temperature data using thermal color table:
%     mphplot(pd, 'index', 1, 'colortable', 'Thermal', 'rangenum', 1)
%
%   (*) The plot on server option requires that you start COMSOL with
%   MATLAB in graphics mode.
%
%   See also: colortable, mpheval

%   Copyright 2010-2023 COMSOL
