function mphviewselection(model,varargin)
% MPHVIEWSELECTION Display a geometric entity selection in a MATLAB figure
%
%   MPHVIEWSELECTION(MODEL,GEOMTAG,NUMBER,ENTITY,...) displays
%   the geometric entity NUMBER of type ENTITY in a MATLAB figure including
%   the representation of the geometry defined with the tag GEOMTAG.
%
%   MPHVIEWSELECTION(MODEL,SELTAG,...) displays the geometric entity
%   selection defined with the tag SELTAG in a MATLAB figure including the
%   representation of the model geometry.
%
%   Valid property/value pairs include:
%   Property            Value/{Default}    Description
%   -----------------------------------------------------------------------
%   edgecolor           Char{'k'} |        Color for edges
%                       RGB array
%   edgecolorselected   RGB array{[1,0,0]} Color for selected edges
%   edgelabels          'on' | {'off'}     Show edge labels
%   edgelabelscolor     Char{'g'} |        Color for edge labels
%                       RGB array
%   edgemode            {'on'} | 'off'     Show edges
%   entity              {[]} | 'domain' |  Set the selected entity type
%                       'boundary' |
%                       'edge' | 'point'
%   facealpha           Double {1}         Set transparency value
%   facecolor           RGB array          Color for faces
%                       {[0.6 0.6 0.6]}
%   facecolorselected   RGB array{[1,0,0]} Color for selected faces
%   facelabels          'on' | {'off'}     Show face labels
%   facelabelscolor     Char{'b'} |        Color for face labels
%                       RGB array
%   facemode            {'on'} | 'off'     Show faces
%   geommode            {'on'} | 'off'     Show entire geometry
%   marker              {'.'}              Vertex marker
%   markercolorselected Char{'r'} |        Color for selected vertex marker
%                       RGB array
%   markersize          Int {12}           Font size of marker
%   objects             Cell array         Selection matrix
%   parent              Double             Parent axis
%   renderer            {'opengl'} |       Set the rendering method
%                       'zbuffer'
%   selection           String| Positive   Set selection tag or entity
%                       integer vector |   number
%                        {[]}
%   selectoralpha       Double {0.25}      Set selector transparency value
%   selectorcolor       RGB array{[0 0 1]} Color for selector
%   showselector        {'on'} | 'off'     Show Selector
%   vertexlabels        'on' | {'off'}     Show vertex labels
%   vertexlabelscolor   Char{'r'} |        Color for vertex labels
%                       RGB array
%   vertexmode          'on' | {'off'}     Show vertices
%
%
%   Example :
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%
%     % Plot boundary 6 using yellow color:
%     mphviewselection(model,'geom1',6,'entity','boundary',...
%       'facecolorselected',[1 1 0],'facealpha',0.5)
%
%     % Plot edges 1 to 8 using green color:
%     mphviewselection(model,'geom1',1:8,'entity','edge',...
%       'edgecolorselected',[0 1 0])
%
%     % Add an explicit selection for boundaries 7 to 12
%     model.selection.create('sel1','Explicit').geom(2).set(7:12);
%     % Plot the selection in figure:
%     mphviewselection(model,'sel1');
%
%     % Add a selection to get the vertex indices with the box delimited
%     % with the coordinates [-1e-3 11e-3;-1e-3 11e-3;9e-3 11e-3]:
%     box = model.selection.create('box1', 'Box');
%     box.set('entitydim', '0');
%     box.set('xmin', '-1e-3').set('xmax', '11e-3');
%     box.set('ymin', '-1e-3').set('ymax', '11e-3');
%     box.set('zmin', '10e-3').set('zmax', '11e-3');
%     % Plot the selected entities and the selector:
%     mphviewselection(model,'box1','facemode','off');
%
%   See also: mphgeom, mphselectbox, mphselectcoords

%   Copyright 2011-2023 COMSOL
